@@ -6,8 +6,6 @@ Portions Copyright (c) 2021 Emre Hasegeli
 """
 
 from githooks.commit_checks import (
-    CheckCommitMessage,
-    CheckCommitSummary,
     CheckChangedFilePaths,
     CheckBinaryFiles,
 )
